Crate token_address_extractor

Statics

FUNCTIONS
A collection of functions that extract blockchain addresses.

Functions

extract_ethereum_based_address
Extracts the first Ethereum-based address from a given text.
extract_solana_address
Extracts the first Solana address from a given text.
extract_token_address_from_message_text
Extracts the first token address (Ethereum-based, Solana, or Tron) found in a given text.
extract_tron_address
Extracts the first Tron address from a given text.