Statics
- FUNCTIONS
- A collection of functions that extract blockchain addresses.
Functions
- extract_
ethereum_ based_ address - Extracts the first Ethereum-based address from a given text.
- extract_
solana_ address - Extracts the first Solana address from a given text.
- extract_
token_ address_ from_ message_ text - Extracts the first token address (Ethereum-based, Solana, or Tron) found in a given text.
- extract_
tron_ address - Extracts the first Tron address from a given text.